pub struct HandlerInfo {
pub typename: Cow<'static, str>,
pub arm: Option<Cow<'static, str>>,
}Expand description
Information about a message handler being processed.
Uses Cow<'static, str> to avoid string copies on the hot path.
The typename and arm are typically static strings from TypeInfo.
Fields
typename: Cow<'static, str>The type name of the message being handled.
arm: Option<Cow<'static, str>>The enum arm being handled, if the message is an enum.
Implementations
Sourceimpl HandlerInfo
impl HandlerInfo
Sourcepub fn from_static(typename: &'static str, arm: Option<&'static str>) -> Self
pub fn from_static(typename: &'static str, arm: Option<&'static str>) -> Self
Create a new HandlerInfo from static strings (zero-copy).
Sourcepub fn from_owned(typename: String, arm: Option<String>) -> Self
pub fn from_owned(typename: String, arm: Option<String>) -> Self
Create a new HandlerInfo from owned strings.